@@ -35,7 +35,7 @@ done
 
 [ -x $MNT/execute ] && $MNT/execute
 
-umount $FLOPPY
+umount $MNT
 
 # If something has been changed in /etc/inittab
 init q
